@@ -110,6 +110,8 @@ public class SettingsAction extends AbstractDriveAction {
                 jsonObject.put("serverVersion", settings.getServerVersion());
                 jsonObject.put("supportedApiVersion", settings.getSupportedApiVersion());
                 jsonObject.put("minApiVersion", settings.getMinApiVersion());
+                jsonObject.put("localizedFolderNames", settings.getLocalizedFolders());
+                jsonObject.put("capabilities", settings.getCapabilities());
             } catch (JSONException e) {
                 throw AjaxExceptionCodes.JSON_ERROR.create(e, e.getMessage());
             }
