@@ -79,6 +79,7 @@ public class DefaultDriveSession implements DriveSession {
     private List<DriveFileField> fields;
     private List<FilePattern> fileExclusions;
     private List<DirectoryPattern> directoryExclusions;
+    private Boolean useDriveMeta;
 
     /**
      * Initializes a new {@link DefaultDriveSession}.
@@ -145,6 +146,16 @@ public class DefaultDriveSession implements DriveSession {
         this.directoryExclusions = directoryExclusions;
     }
 
+    /**
+     * Overrides if drive metadata synchronization should be enabled or not, independently of the used API version.
+     *
+     * @param useDriveMeta <code>true</code> to force drive meta synchronization, <code>false</code> to forcibly disable it, or
+     *        <code>null</code> to decide based on the API version
+     */
+    public void setUseDriveMeta(Boolean useDriveMeta) {
+        this.useDriveMeta = useDriveMeta;
+    }
+
     @Override
     public String getRootFolderID() {
         return rootFolderID;
@@ -215,10 +226,16 @@ public class DefaultDriveSession implements DriveSession {
         return fileExclusions;
     }
 
+    @Override
+    public boolean useDriveMeta() {
+        return null != useDriveMeta ? useDriveMeta.booleanValue() : 3 <= apiVersion;
+    }
+
     @Override
     public String toString() {
         return "DriveSession [sessionID=" + session.getSessionID() + ", rootFolderID=" + rootFolderID + ", contextID=" +
             session.getContextId() + ", clientVersion=" + clientVersion + ", deviceName=" + deviceName + ", apiVersion=" +
             apiVersion + ", diagnostics=" + diagnostics + "]";
     }
+
 }
