@@ -49,7 +49,39 @@
 
 package com.openexchange.drive;
 
-import static com.openexchange.drive.DriveExceptionMessages.*;
+import static com.openexchange.drive.DriveExceptionMessages.CLIENT_OUTDATED_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.CLIENT_VERSION_UPDATE_AVAILABLE_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.CONFLICTING_FILENAME_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.CONFLICTING_PATH_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.DIRECTORYVERSION_NOT_FOUND_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.FILEVERSION_NOT_FOUND_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.FILE_NOT_FOUND_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.IGNORED_FILENAME_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.IGNORED_PATH_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.INVALID_DIRECTORYVERSION_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.INVALID_FILENAME_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.INVALID_FILEVERSION_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.INVALID_FILE_OFFSET_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.INVALID_PATH_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.INVALID_PATTERN_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.LEVEL_CONFLICTING_FILENAME_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.LEVEL_CONFLICTING_PATH_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.LONG_POLLING_NOT_AVAILABLE_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.METDATA_PARSE_ERROR_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.NOT_SYNCHRONIZABLE_DIRECTORY_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.NO_CREATE_DIRECTORY_PERMISSION_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.NO_CREATE_FILE_PERMISSION_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.NO_DELETE_DIRECTORY_PERMISSION_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.NO_DELETE_FILE_PERMISSION_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.NO_MODIFY_FILE_PERMISSION_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.PATH_NOT_FOUND_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.QUOTA_REACHED_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.REPEATED_SYNC_PROBLEMS_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.SERVER_BUSY_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.TOKEN_ALREADY_REGISTERED_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.TOO_MANY_DIRECTORIES_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.TOO_MANY_FILES_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.UPLOADED_FILE_CHECKSUM_ERROR_MSG;
 import com.openexchange.exception.Category;
 import com.openexchange.exception.DisplayableOXExceptionCode;
 import com.openexchange.exception.OXException;
@@ -156,9 +188,27 @@ public enum DriveExceptionCodes implements DisplayableOXExceptionCode {
     /** The file name \"%1$s\" is conflicting with an equally named directory at \"%2$s\". */
     LEVEL_CONFLICTING_FILENAME(LEVEL_CONFLICTING_FILENAME_MSG, LEVEL_CONFLICTING_FILENAME_MSG, Category.CATEGORY_CONFLICT, 31),
 
-    /** "The path \"%1$s\" is conflicting with an equally named file at \"%2$s\"." */
+    /** The path \"%1$s\" is conflicting with an equally named file at \"%2$s\". */
     LEVEL_CONFLICTING_PATH(LEVEL_CONFLICTING_PATH_MSG, LEVEL_CONFLICTING_PATH_MSG, Category.CATEGORY_CONFLICT, 32),
 
+    /** The directory \"%1$s\" is not synchronizable. Please select another directory. */
+    NOT_SYNCHRONIZABLE_DIRECTORY(NOT_SYNCHRONIZABLE_DIRECTORY_MSG, NOT_SYNCHRONIZABLE_DIRECTORY_MSG, Category.CATEGORY_USER_INPUT, 33),
+
+    /** The supplied metadata could not be parsed: \"%1$s\" */
+    METDATA_PARSE_ERROR(METDATA_PARSE_ERROR_MSG, METDATA_PARSE_ERROR_MSG, Category.CATEGORY_USER_INPUT, 34),
+
+    /** The maximum number of synchronizable directories (%1$d) is exceeded. Please remove some directories and try again, or select another root folder. */
+    TOO_MANY_DIRECTORIES(TOO_MANY_DIRECTORIES_MSG, TOO_MANY_DIRECTORIES_MSG, Category.CATEGORY_CAPACITY, 35),
+
+    /** The maximum number of files (%1$d) is exceeded in directory \"%2$s\". Please remove some files and try again. */
+    TOO_MANY_FILES(TOO_MANY_FILES_MSG, TOO_MANY_FILES_MSG, Category.CATEGORY_CAPACITY, 36),
+
+    /** The token \"%1$s\" is already registered. */
+    TOKEN_ALREADY_REGISTERED(TOKEN_ALREADY_REGISTERED_MSG, TOKEN_ALREADY_REGISTERED_MSG, Category.CATEGORY_CONFLICT, 37),
+
+    /** Client connection lost unexpectedly */
+    CLIENT_CONNECTION_LOST("Client connection lost unexpectedly", OXExceptionStrings.MESSAGE, Category.CATEGORY_CONNECTIVITY, 38),
+
     ;
 
     private static final String PREFIX = "DRV";
